require(ape, quietly = TRUE)
cynipids <- read.nexus.data("cynipids.txt")

